=====
bs_ds
=====


.. image:: https://img.shields.io/pypi/v/bs_ds.svg
        :target: https://pypi.python.org/pypi/bs_ds

.. image:: https://img.shields.io/travis/jirvingphd/bs_ds.svg
        :target: https://travis-ci.org/jirvingphd/bs_ds

.. image:: https://readthedocs.org/projects/bs-ds/badge/?version=latest
        :target: https://bs-ds.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A collection of tools from bootcamp.


* Free software: GNU General Public License v3
* Documentation: https://bs-ds.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
